@@ -431,10 +431,7 @@ def _drop_dup_dummies(gen: List[DocStore]) -> Generator[DocStore, None, None]:
             continue
 
         assert elm.doc_tok.offset == element.doc_tok.offset
-        if (
-            isinstance(element, DummyElement)
-            and elm.doc_tok.fname == element.doc_tok.fname
-        ):
+        if isinstance(element, DummyElement) and elm.doc_tok.fname == element.doc_tok.fname:
             element = elm  # 'element' is not useful, 'elm' cannot be worse!
             continue
 
