@@ -37,9 +37,7 @@ class _DumpSpec:
     """Class for dumping the specification to an output stream."""
 
     def __init__(self, output_stream: Optional[TextIO] = None):
-        self.stream = (
-            click.get_text_stream("stdout") if output_stream is None else output_stream
-        )
+        self.stream = click.get_text_stream("stdout") if output_stream is None else output_stream
         self.done_types: Dict[types.BaseType, int] = {}
 
     def dump(self, spec: Specification):
@@ -48,9 +46,7 @@ class _DumpSpec:
         """
         self.stream.write("\nTYPES:\n")
         if spec.types:
-            text_tdefs = [
-                (tdef.name, self._dump_type(tdef.type)) for tdef in spec.types.values()
-            ]
+            text_tdefs = [(tdef.name, self._dump_type(tdef.type)) for tdef in spec.types.values()]
             self.stream.write("\n")
             for name, tname in text_tdefs:
                 self.stream.write("typedef {}: {}\n".format(name.tok_text, tname))
@@ -67,9 +63,7 @@ class _DumpSpec:
             for param in rel_def.params:
                 tnumber = self.done_types[param.type]
                 param_type = "type#{}".format(tnumber)
-                text = "{} {}: {}".format(
-                    param.direction, param.name.tok_text, param_type
-                )
+                text = "{} {}: {}".format(param.direction, param.name.tok_text, param_type)
                 if param.multi:
                     text = "multi " + text
 
@@ -96,9 +90,7 @@ class _DumpSpec:
         # Dump variables of a component definition.
         leading = "        "
         for vdef in compdef.variables:
-            self.stream.write(
-                "{}var {}\n{}  ".format(leading, vdef.name_tok.tok_text, leading)
-            )
+            self.stream.write("{}var {}\n{}  ".format(leading, vdef.name_tok.tok_text, leading))
             self._dump_nodes(vdef.node, prefixes=[leading + "  "])
 
         # Dump parameters of a component definition.
@@ -110,9 +102,7 @@ class _DumpSpec:
 
         # Dump variable groups of a component definition.
         for vgroup in compdef.var_groups:
-            content = ", ".join(
-                varpart.tok_text for varpart in vgroup.variablepart_names
-            )
+            content = ", ".join(varpart.tok_text for varpart in vgroup.variablepart_names)
             text = "vgroup {}: {}".format(vgroup.name_tok.tok_text, content)
             self.stream.write(leading + text + "\n  " + leading)
             self._dump_nodes(vgroup.node, prefixes=[leading + "  "])
@@ -120,9 +110,7 @@ class _DumpSpec:
         # Dump component instances of a component definition.
         for compinst in compdef.component_instances:
             def_name = compinst.compdef.name_tok.tok_text
-            text = "child-component {}: def={}".format(
-                compinst.inst_name_tok.tok_text, def_name
-            )
+            text = "child-component {}: def={}".format(compinst.inst_name_tok.tok_text, def_name)
             self.stream.write("        " + text + "\n")
             self._dump_docs(compinst, "        ")
             self._dump_compinst_params(compinst)
@@ -130,9 +118,7 @@ class _DumpSpec:
         # Dump relation instances of a component definition.
         for relinst in compdef.relations:
             def_name = relinst.reldef.name.tok_text
-            text = "relation-instance {}: def={}".format(
-                relinst.inst_name_tok.tok_text, def_name
-            )
+            text = "relation-instance {}: def={}".format(relinst.inst_name_tok.tok_text, def_name)
             self.stream.write("        " + text + "\n")
             self._dump_docs(relinst, "        ")
             self._dump_relinst_params(relinst)
@@ -162,9 +148,7 @@ class _DumpSpec:
 
         # Dump transformations
         for trans in compdef.transforms:
-            name = "{} transform {}:".format(
-                trans.transform_kind, trans.label_tok.tok_text
-            )
+            name = "{} transform {}:".format(trans.transform_kind, trans.label_tok.tok_text)
             comptext = "  {} ({} {})"
             comptext = comptext.format(
                 trans.doesaux_tok.tok_text,
@@ -177,15 +161,11 @@ class _DumpSpec:
             self._dump_docs(trans, indent)
             self.stream.write(indent + comptext + "\n")
             for f in trans.in_flows:
-                self.stream.write(
-                    indent + "  in-flow '{}':\n".format(f.name_tok.tok_text)
-                )
+                self.stream.write(indent + "  in-flow '{}':\n".format(f.name_tok.tok_text))
                 self.stream.write(indent + "  ")
                 self._dump_nodes(f.flow_node, prefixes=[indent + "  "])
             for f in trans.out_flows:
-                self.stream.write(
-                    indent + "  out-flow '{}':\n".format(f.name_tok.tok_text)
-                )
+                self.stream.write(indent + "  out-flow '{}':\n".format(f.name_tok.tok_text))
                 self.stream.write(indent + "  ")
                 self._dump_nodes(f.flow_node, prefixes=[indent + "  "])
             self._dump_subclauses(trans.sub_clauses)
@@ -213,9 +193,7 @@ class _DumpSpec:
 
         # Dump behavior
         for behavior in compdef.behaviors:
-            name = "{} behavior {}:".format(
-                behavior.behavior_kind, behavior.name_tok.tok_text
-            )
+            name = "{} behavior {}:".format(behavior.behavior_kind, behavior.name_tok.tok_text)
             self.stream.write("        " + name + "\n")
             self._dump_docs(behavior, "        ")
             for case in behavior.cases:
@@ -241,9 +219,7 @@ class _DumpSpec:
                 # Construct text and node for RHS
                 rv = ex.rhs_varval
                 if isinstance(rv, Value):
-                    rhs_text = "{}[{}]".format(
-                        rv.value.tok_text, next(iter(rv.get_units()))
-                    )
+                    rhs_text = "{}[{}]".format(rv.value.tok_text, next(iter(rv.get_units())))
                     rhs_node = None
                 else:
                     assert isinstance(rv, VariableValue)
@@ -367,9 +343,7 @@ class _DumpSpec:
             type_names = [self._dump_type(field.type) for field in btp.fields]
             self.stream.write("{} = bundle\n".format(my_typename))
             for field, tname in zip(btp.fields, type_names):
-                self.stream.write(
-                    indent + "{}: {}\n".format(field.name.tok_text, tname)
-                )
+                self.stream.write(indent + "{}: {}\n".format(field.name.tok_text, tname))
             self.stream.write("{} end\n".format(my_typename))
             self.stream.write("\n")
 
@@ -382,9 +356,7 @@ class _DumpSpec:
                 self.stream.write("{} = type\n".format(my_typename))
 
             if btp.units:
-                self.stream.write(
-                    "    units: " + ", ".join(u.tok_text for u in btp.units) + "\n"
-                )
+                self.stream.write("    units: " + ", ".join(u.tok_text for u in btp.units) + "\n")
 
             if btp.intervals:
                 prefix = "    intervals: "
@@ -398,9 +370,7 @@ class _DumpSpec:
                     else:
                         ubound = str(ival[1])
 
-                    self.stream.write(
-                        prefix + "(=> {}, <= {})\n".format(lbound, ubound)
-                    )
+                    self.stream.write(prefix + "(=> {}, <= {})\n".format(lbound, ubound))
                     prefix = " " * len(prefix)
 
         return my_typename
