@@ -20,17 +20,12 @@ Diagnostic code scheme:
 """
 
 import sys
-from typing import Iterable, List, Optional
-from typing.io import IO
+from typing import IO, Iterable, List, Optional
 
 import click
+
 from raesl import logger, utils
-from raesl.types import (
-    Diagnostic,
-    DiagnosticRelatedInformation,
-    DiagnosticSeverity,
-    Location,
-)
+from raesl.types import Diagnostic, DiagnosticRelatedInformation, DiagnosticSeverity, Location
 
 # Proxies
 ERROR = DiagnosticSeverity.Error
@@ -163,9 +158,7 @@ def E100(location: Location = utils.get_location()) -> EslDiagnostic:
     )
 
 
-def E101(
-    acceptors: Iterable[str], location: Location = utils.get_location()
-) -> EslDiagnostic:
+def E101(acceptors: Iterable[str], location: Location = utils.get_location()) -> EslDiagnostic:
     """Best line match is ambiguous. Found multiple acceptors: {ambi_acceptors}. This
     is an internal error.
     """
@@ -207,15 +200,11 @@ def E200(
         severity=ERROR,
         code="E200",
         source="ESL typechecker",
-        related_information=[
-            EslRelated(dupe, f"Duplicate {kind} '{name}'.") for dupe in dupes
-        ],
+        related_information=[EslRelated(dupe, f"Duplicate {kind} '{name}'.") for dupe in dupes],
     )
 
 
-def E201(
-    section: str, context: str, location: Location = utils.get_location()
-) -> EslDiagnostic:
+def E201(section: str, context: str, location: Location = utils.get_location()) -> EslDiagnostic:
     """This '{section}' section is not allowed in the '{context}' context."""
     return EslDiagnostic(
         f"This '{section}' section is not allowed in the '{context}' context.",
@@ -283,9 +272,7 @@ def E204(
     )
 
 
-def E205(
-    name: str, context: str, location: Location = utils.get_location()
-) -> EslDiagnostic:
+def E205(name: str, context: str, location: Location = utils.get_location()) -> EslDiagnostic:
     """Cannot find {name} in {context}."""
     return EslDiagnostic(
         f"Cannot find {name} in {context}.",
@@ -315,9 +302,7 @@ def E206(
         severity=ERROR,
         code="E206",
         source="ESL typechecker",
-        related_information=[
-            EslRelated(block, f"Relation {kind} block") for block in blocks
-        ],
+        related_information=[EslRelated(block, f"Relation {kind} block") for block in blocks],
     )
 
 
@@ -334,9 +319,7 @@ def E207(
         severity=ERROR,
         code="E207",
         source="ESL typechecker",
-        related_information=[
-            EslRelated(definition, "Corresponding relation definition.")
-        ],
+        related_information=[EslRelated(definition, "Corresponding relation definition.")],
     )
 
 
@@ -354,9 +337,7 @@ def E208(
         severity=ERROR,
         code="E208",
         source="ESL typechecker",
-        related_information=[
-            EslRelated(definition, "Corresponding relation definition.")
-        ],
+        related_information=[EslRelated(definition, "Corresponding relation definition.")],
     )
 
 
@@ -375,15 +356,11 @@ def E209(
         severity=ERROR,
         code="E209",
         source="ESL typechecker",
-        related_information=[
-            EslRelated(other, f"{other_kind} location.") for other in others
-        ],
+        related_information=[EslRelated(other, f"{other_kind} location.") for other in others],
     )
 
 
-def E210(
-    lhs: Location, rhs: Location, reason: str = "are not compatible"
-) -> EslDiagnostic:
+def E210(lhs: Location, rhs: Location, reason: str = "are not compatible") -> EslDiagnostic:
     """Values cannot be compared, they {reason}."""
     return EslDiagnostic(
         f"Values cannot be compared, they {reason}.",
@@ -446,9 +423,7 @@ def E213(
         severity=ERROR,
         code="E213",
         source="ESL typechecker",
-        related_information=[
-            EslRelated(occ, f"{kind.capitalize()}") for occ in occurrences
-        ],
+        related_information=[EslRelated(occ, f"{kind.capitalize()}") for occ in occurrences],
     )
 
 
@@ -465,9 +440,7 @@ def E214(
         severity=ERROR,
         code="E214",
         source="ESL typechecker",
-        related_information=[
-            EslRelated(loc, "Related type definition.") for loc in def_locs
-        ],
+        related_information=[EslRelated(loc, "Related type definition.") for loc in def_locs],
     )
 
 
@@ -534,9 +507,7 @@ def E219(name: str, location: Location = utils.get_location()) -> EslDiagnostic:
     )
 
 
-def E220(
-    name: str, kind: str, location: Location = utils.get_location()
-) -> EslDiagnostic:
+def E220(name: str, kind: str, location: Location = utils.get_location()) -> EslDiagnostic:
     """Element '{name}' does not match with a {kind}."""
     return EslDiagnostic(
         f"Element '{name}' does not match with a {kind}.",
@@ -563,8 +534,7 @@ def E221(
         code="E221",
         source="ESL typechecker",
         related_information=[
-            EslRelated(ref, f"Reference with {expected} {kind}(s).")
-            for ref in references
+            EslRelated(ref, f"Reference with {expected} {kind}(s).") for ref in references
         ],
     )
 
@@ -647,9 +617,7 @@ def E226(
         severity=ERROR,
         code="E226",
         source="ESL typechecker",
-        related_information=[
-            EslRelated(location, "Only elementary variables, try its fields.")
-        ],
+        related_information=[EslRelated(location, "Only elementary variables, try its fields.")],
     )
 
 
@@ -667,9 +635,18 @@ def E227(
         severity=ERROR,
         code="E200",
         source="ESL typechecker",
-        related_information=[
-            EslRelated(dupe, f"Duplicate identifier '{name}'.") for dupe in dupes
-        ],
+        related_information=[EslRelated(dupe, f"Duplicate identifier '{name}'.") for dupe in dupes],
+    )
+
+
+def E228(lhs: Location, rhs: Location, reason: str = "are not compatible") -> EslDiagnostic:
+    """Values cannot be compared, design rule {reason}."""
+    return EslDiagnostic(
+        f"Values cannot be compared, design rule {reason}.",
+        location=lhs,
+        severity=ERROR,
+        code="E228",
+        source="ESL typechecker",
     )
 
 
