@@ -8,15 +8,16 @@ from copy import deepcopy
 from itertools import chain
 from typing import Any, Dict, Generator, Iterable, List, Optional, Set, Tuple
 
-from raesl import logger
-from raesl.compile import diagnostics
-from raesl.compile.instantiating.node_building import NodeStore
 from ragraph.edge import Edge
 from ragraph.node import Node
 
+from raesl import logger
+from raesl.compile import diagnostics
+from raesl.compile.instantiating.node_building import NodeStore
+
 
 class EdgeStore:
-    """Edge storage with multiple catagories for quicker access to specific subsets."""
+    """Edge storage with multiple categories for quicker access to specific subsets."""
 
     categories = ["edges"]  # Updated in EdgeFactory init.
 
@@ -52,9 +53,7 @@ class EdgeFactory:
         self.node_store = node_store
 
         # Set categories dynamically.
-        EdgeStore.categories = ["edges"] + [
-            i[6:] for i in dir(self) if i.startswith("_make_")
-        ]
+        EdgeStore.categories = ["edges"] + [i[6:] for i in dir(self) if i.startswith("_make_")]
         self.edge_store = EdgeStore()
 
     def _add(self, edge: Edge, *args):
@@ -111,9 +110,7 @@ class EdgeFactory:
                             kind="functional_dependency",
                             labels=[nodes[vi].annotations.esl_info["type_ref"]],
                             annotations=dict(
-                                esl_info=dict(
-                                    reason=dict(function_specifications=[t.name])
-                                )
+                                esl_info=dict(reason=dict(function_specifications=[t.name]))
                             ),
                         ),
                         "evf",
@@ -193,9 +190,7 @@ class EdgeFactory:
                             kind="design_dependency",
                             labels=[nodes[vi].annotations.esl_info["type_ref"]],
                             annotations=dict(
-                                esl_info=dict(
-                                    reason=dict(relation_specifications=[r.name])
-                                )
+                                esl_info=dict(reason=dict(relation_specifications=[r.name]))
                             ),
                         ),
                         "evd",
@@ -226,9 +221,7 @@ class EdgeFactory:
                     target=trg,
                     kind="functional_dependency",
                     labels=lbs,
-                    annotations=dict(
-                        esl_info=dict(reason=dict(function_specifications=[g.name]))
-                    ),
+                    annotations=dict(esl_info=dict(reason=dict(function_specifications=[g.name]))),
                 ),
                 "ecf",
             )
@@ -239,9 +232,7 @@ class EdgeFactory:
                     target=src,
                     kind="functional_dependency",
                     labels=lbs,
-                    annotations=dict(
-                        esl_info=dict(reason=dict(function_specifications=[g.name]))
-                    ),
+                    annotations=dict(esl_info=dict(reason=dict(function_specifications=[g.name]))),
                 ),
                 "ecf",
             )
@@ -263,11 +254,7 @@ class EdgeFactory:
                             kind="functional_dependency",
                             labels=lbs,
                             annotations=dict(
-                                esl_info=dict(
-                                    reason=dict(
-                                        function_specifications=[g.name, t.name]
-                                    )
-                                )
+                                esl_info=dict(reason=dict(function_specifications=[g.name, t.name]))
                             ),
                         ),
                         "ecf",
@@ -280,11 +267,7 @@ class EdgeFactory:
                             kind="functional_dependency",
                             labels=lbs,
                             annotations=dict(
-                                esl_info=dict(
-                                    reason=dict(
-                                        function_specifications=[g.name, t.name]
-                                    )
-                                )
+                                esl_info=dict(reason=dict(function_specifications=[g.name, t.name]))
                             ),
                         ),
                         "ecf",
@@ -306,11 +289,7 @@ class EdgeFactory:
                             kind="functional_dependency",
                             labels=lbs,
                             annotations=dict(
-                                esl_info=dict(
-                                    reason=dict(
-                                        function_specifications=[t.name, g.name]
-                                    )
-                                )
+                                esl_info=dict(reason=dict(function_specifications=[t.name, g.name]))
                             ),
                         ),
                         "ecf",
@@ -323,11 +302,7 @@ class EdgeFactory:
                             kind="functional_dependency",
                             labels=lbs,
                             annotations=dict(
-                                esl_info=dict(
-                                    reason=dict(
-                                        function_specifications=[t.name, g.name]
-                                    )
-                                )
+                                esl_info=dict(reason=dict(function_specifications=[t.name, g.name]))
                             ),
                         ),
                         "ecf",
@@ -349,10 +324,7 @@ class EdgeFactory:
                 shared_vars_ji = tj_out_vars.intersection(ti_in_vars)
 
                 if shared_vars_ij:
-                    lbs = [
-                        nodes[v].annotations.esl_info["type_ref"]
-                        for v in shared_vars_ij
-                    ]
+                    lbs = [nodes[v].annotations.esl_info["type_ref"] for v in shared_vars_ij]
                     self._add(
                         Edge(
                             source=nodes[ci],
@@ -361,9 +333,7 @@ class EdgeFactory:
                             labels=lbs,
                             annotations=dict(
                                 esl_info=dict(
-                                    reason=dict(
-                                        function_specifications=[ti.name, tj.name]
-                                    )
+                                    reason=dict(function_specifications=[ti.name, tj.name])
                                 )
                             ),
                         ),
@@ -378,9 +348,7 @@ class EdgeFactory:
                             labels=lbs,
                             annotations=dict(
                                 esl_info=dict(
-                                    reason=dict(
-                                        function_specifications=[ti.name, tj.name]
-                                    )
+                                    reason=dict(function_specifications=[ti.name, tj.name])
                                 )
                             ),
                         ),
@@ -388,10 +356,7 @@ class EdgeFactory:
                     )
 
                 if shared_vars_ji:
-                    lbs = [
-                        nodes[v].annotations.esl_info["type_ref"]
-                        for v in shared_vars_ji
-                    ]
+                    lbs = [nodes[v].annotations.esl_info["type_ref"] for v in shared_vars_ji]
                     self._add(
                         Edge(
                             source=nodes[cj],
@@ -400,9 +365,7 @@ class EdgeFactory:
                             labels=lbs,
                             annotations=dict(
                                 esl_info=dict(
-                                    reason=dict(
-                                        function_specifications=[tj.name, ti.name]
-                                    )
+                                    reason=dict(function_specifications=[tj.name, ti.name])
                                 )
                             ),
                         ),
@@ -417,9 +380,7 @@ class EdgeFactory:
                             labels=lbs,
                             annotations=dict(
                                 esl_info=dict(
-                                    reason=dict(
-                                        function_specifications=[tj.name, ti.name]
-                                    )
+                                    reason=dict(function_specifications=[tj.name, ti.name])
                                 )
                             ),
                         ),
@@ -482,14 +443,12 @@ class EdgeFactory:
                                         source=ai,
                                         target=aj,
                                         kind="design_dependency",
-                                        labels=[
-                                            nodes[pi].annotations.esl_info["type_ref"]
-                                        ],
+                                        labels=[nodes[pi].annotations.esl_info["type_ref"]],
                                         annotations=dict(
                                             esl_info=dict(
-                                                reason=e_dict[
-                                                    (pi, pj)
-                                                ].annotations.esl_info["reason"]
+                                                reason=e_dict[(pi, pj)].annotations.esl_info[
+                                                    "reason"
+                                                ]
                                             )
                                         ),
                                     ),
@@ -533,20 +492,14 @@ class EdgeFactory:
                                 kind="functional_dependency",
                                 labels=[nodes[vi].annotations.esl_info["type_ref"]],
                                 annotations=dict(
-                                    esl_info=dict(
-                                        reason=dict(function_specifications=[t.name])
-                                    )
+                                    esl_info=dict(reason=dict(function_specifications=[t.name]))
                                 ),
                             )
                         )
 
             for t in ctd[c.name]:
-                srcs = [
-                    nodes[v] for v in t.annotations.esl_info["body"]["input_variables"]
-                ]
-                trgs = [
-                    nodes[v] for v in t.annotations.esl_info["body"]["output_variables"]
-                ]
+                srcs = [nodes[v] for v in t.annotations.esl_info["body"]["input_variables"]]
+                trgs = [nodes[v] for v in t.annotations.esl_info["body"]["output_variables"]]
 
                 paths = _get_paths_between_all(srcs=srcs, trgs=set(trgs), edges=evf_c)
 
@@ -566,9 +519,7 @@ class EdgeFactory:
                                 kind="traceability_dependency",
                                 annotations=dict(
                                     esl_info=dict(
-                                        reason=dict(
-                                            path_variables=list(shared_path_variables)
-                                        )
+                                        reason=dict(path_variables=list(shared_path_variables))
                                     )
                                 ),
                             ),
@@ -587,9 +538,7 @@ class EdgeFactory:
                                 kind="traceability_dependency",
                                 annotations=dict(
                                     esl_info=dict(
-                                        reason=dict(
-                                            path_variables=list(shared_path_variables)
-                                        )
+                                        reason=dict(path_variables=list(shared_path_variables))
                                     )
                                 ),
                             ),
@@ -638,9 +587,7 @@ class EdgeFactory:
 
                 vin_shared = tvin.intersection(gv)
                 if vin_shared:
-                    lbs = [
-                        nodes[v].annotations.esl_info["type_ref"] for v in vin_shared
-                    ]
+                    lbs = [nodes[v].annotations.esl_info["type_ref"] for v in vin_shared]
                     self._add(
                         Edge(
                             source=g,
@@ -648,18 +595,14 @@ class EdgeFactory:
                             kind="functional_dependency",
                             labels=lbs,
                             annotations=dict(
-                                esl_info=dict(
-                                    reason=dict(shared_variables=list(vin_shared))
-                                )
+                                esl_info=dict(reason=dict(shared_variables=list(vin_shared)))
                             ),
                         ),
                         "eff",
                     )
                 vout_shared = tvout.intersection(gv)
                 if vout_shared:
-                    lbs = [
-                        nodes[v].annotations.esl_info["type_ref"] for v in vout_shared
-                    ]
+                    lbs = [nodes[v].annotations.esl_info["type_ref"] for v in vout_shared]
                     self._add(
                         Edge(
                             source=t1,
@@ -667,9 +610,7 @@ class EdgeFactory:
                             kind="functional_dependency",
                             labels=lbs,
                             annotations=dict(
-                                esl_info=dict(
-                                    reason=dict(shared_variables=list(vout_shared))
-                                )
+                                esl_info=dict(reason=dict(shared_variables=list(vout_shared)))
                             ),
                         ),
                         "eff",
@@ -752,9 +693,7 @@ class EdgeFactory:
                         labels=lbs,
                         annotations=dict(
                             esl_info=dict(
-                                reason=dict(
-                                    shared_variables=[v.name for v in shared_vars]
-                                )
+                                reason=dict(shared_variables=[v.name for v in shared_vars])
                             )
                         ),
                     ),
@@ -794,9 +733,7 @@ class EdgeFactory:
                         labels=lbs,
                         annotations=dict(
                             esl_info=dict(
-                                reason=dict(
-                                    shared_variables=[v.name for v in shared_vars]
-                                )
+                                reason=dict(shared_variables=[v.name for v in shared_vars])
                             )
                         ),
                     ),
@@ -828,14 +765,10 @@ class EdgeFactory:
                         source=di,
                         target=dj,
                         kind="coordination_dependency",
-                        labels=[
-                            v.annotations.esl_info["type_ref"] for v in shared_vars
-                        ],
+                        labels=[v.annotations.esl_info["type_ref"] for v in shared_vars],
                         annotations=dict(
                             esl_info=dict(
-                                reason=(
-                                    dict(shared_variables=[v.name for v in shared_vars])
-                                )
+                                reason=(dict(shared_variables=[v.name for v in shared_vars]))
                             )
                         ),
                     ),
@@ -850,23 +783,18 @@ class EdgeFactory:
                 if ni == nj:
                     continue
 
-                if (
-                    not ni.annotations.esl_info["subject"]
-                    == nj.annotations.esl_info["subject"]
-                ):
+                if not ni.annotations.esl_info["subject"] == nj.annotations.esl_info["subject"]:
                     continue
 
                 self._add(
                     Edge(
                         source=ni,
                         target=nj,
-                        kind="mapping_dependency",
+                        kind="coordination_dependency",
                         labels=["shared subject"],
                         annotations=dict(
                             esl_info=dict(
-                                reason=dict(
-                                    shared_subject=ni.annotations.esl_info["subject"]
-                                )
+                                reason=dict(shared_subject=ni.annotations.esl_info["subject"])
                             )
                         ),
                     ),
@@ -902,13 +830,8 @@ class EdgeFactory:
                         source=ri,
                         target=rj,
                         kind="coordination_dependency",
-                        labels=[
-                            nodes[v].annotations.esl_info["type_ref"]
-                            for v in shared_vars
-                        ],
-                        annotations=dict(
-                            esl_info=dict(reason=dict(shared_vars=list(shared_vars)))
-                        ),
+                        labels=[nodes[v].annotations.esl_info["type_ref"] for v in shared_vars],
+                        annotations=dict(esl_info=dict(reason=dict(shared_vars=list(shared_vars)))),
                     ),
                     "erc",
                 )
@@ -945,12 +868,8 @@ class EdgeFactory:
             a = n2c[g.annotations.esl_info["body"]["active"]]
             p = n2c[g.annotations.esl_info["body"]["passive"]]
 
-            self._add(
-                Edge(source=a, target=g, labels=lbs, kind="mapping_dependency"), "mcf"
-            )
-            self._add(
-                Edge(source=p, target=g, labels=lbs, kind="mapping_dependency"), "mcf"
-            )
+            self._add(Edge(source=a, target=g, labels=lbs, kind="mapping_dependency"), "mcf")
+            self._add(Edge(source=p, target=g, labels=lbs, kind="mapping_dependency"), "mcf")
 
             for d in a.descendants:
                 if not ctd.get(d):
@@ -958,8 +877,7 @@ class EdgeFactory:
 
                 for t in ctd[d]:
                     outvars = set(
-                        nodes[v]
-                        for v in t.annotations.esl_info["body"]["output_variables"]
+                        nodes[v] for v in t.annotations.esl_info["body"]["output_variables"]
                     )
                     shared_vars = outvars.intersection(gvs)
 
@@ -968,10 +886,7 @@ class EdgeFactory:
                             Edge(
                                 source=d,
                                 target=g,
-                                labels=[
-                                    v.annotations.esl_info["type_ref"]
-                                    for v in shared_vars
-                                ],
+                                labels=[v.annotations.esl_info["type_ref"] for v in shared_vars],
                                 kind="mapping_dependency",
                             ),
                             "mcf",
@@ -980,8 +895,7 @@ class EdgeFactory:
             for d in p.descendants:
                 for t in ctd[d]:
                     invars = set(
-                        nodes[v]
-                        for v in t.annotations.esl_info["body"]["input_variables"]
+                        nodes[v] for v in t.annotations.esl_info["body"]["input_variables"]
                     )
                     shared_vars = invars.intersection(gvs)
 
@@ -990,10 +904,7 @@ class EdgeFactory:
                             Edge(
                                 source=d,
                                 target=g,
-                                labels=[
-                                    v.annotations.esl_info["type_ref"]
-                                    for v in shared_vars
-                                ],
+                                labels=[v.annotations.esl_info["type_ref"] for v in shared_vars],
                                 kind="mapping_dependency",
                             ),
                             "mcf",
@@ -1177,14 +1088,10 @@ class EdgeFactory:
                             source=c,
                             target=d,
                             kind="mapping_dependency",
-                            labels=[
-                                v.annotations.esl_info["type_ref"] for v in shared_vars
-                            ],
+                            labels=[v.annotations.esl_info["type_ref"] for v in shared_vars],
                             annotations=dict(
                                 esl_info=dict(
-                                    reason=dict(
-                                        shared_variables=[v.name for v in shared_vars]
-                                    )
+                                    reason=dict(shared_variables=[v.name for v in shared_vars])
                                 )
                             ),
                         ),
@@ -1220,13 +1127,8 @@ class EdgeFactory:
                         source=c,
                         target=r,
                         kind="mapping_dependency",
-                        labels=[
-                            nodes[v].annotations.esl_info["type_ref"]
-                            for v in shared_vars
-                        ],
-                        annotations=dict(
-                            esl_info=dict(reason=dict(shared_vars=list(shared_vars)))
-                        ),
+                        labels=[nodes[v].annotations.esl_info["type_ref"] for v in shared_vars],
+                        annotations=dict(esl_info=dict(reason=dict(shared_vars=list(shared_vars)))),
                     ),
                     "mcr",
                 )
@@ -1299,13 +1201,8 @@ class EdgeFactory:
                         source=f,
                         target=d,
                         kind="mapping_dependency",
-                        labels=[
-                            nodes[v].annotations.esl_info["type_ref"]
-                            for v in shared_vars
-                        ],
-                        annotations=dict(
-                            esl_info=dict(reason=dict(shared_vars=list(shared_vars)))
-                        ),
+                        labels=[nodes[v].annotations.esl_info["type_ref"] for v in shared_vars],
+                        annotations=dict(esl_info=dict(reason=dict(shared_vars=list(shared_vars)))),
                     ),
                     "mfd",
                 )
@@ -1346,13 +1243,8 @@ class EdgeFactory:
                         source=f,
                         target=r,
                         kind="mapping_dependency",
-                        labels=[
-                            nodes[v].annotations.esl_info["type_ref"]
-                            for v in shared_vars
-                        ],
-                        annotations=dict(
-                            esl_info=dict(reason=dict(shared_vars=list(shared_vars)))
-                        ),
+                        labels=[nodes[v].annotations.esl_info["type_ref"] for v in shared_vars],
+                        annotations=dict(esl_info=dict(reason=dict(shared_vars=list(shared_vars)))),
                     ),
                     "mfr",
                 )
@@ -1385,14 +1277,9 @@ class EdgeFactory:
                             source=b,
                             target=d,
                             kind="mapping_dependency",
-                            labels=[
-                                nodes[v].annotations.esl_info["type_ref"]
-                                for v in shared_vars
-                            ],
+                            labels=[nodes[v].annotations.esl_info["type_ref"] for v in shared_vars],
                             annotations=dict(
-                                esl_info=dict(
-                                    reason=dict(shared_vars=list(shared_vars))
-                                )
+                                esl_info=dict(reason=dict(shared_vars=list(shared_vars)))
                             ),
                         ),
                         "mbd",
@@ -1431,14 +1318,9 @@ class EdgeFactory:
                             source=b,
                             target=r,
                             kind="mapping_dependency",
-                            labels=[
-                                nodes[v].annotations.esl_info["type_ref"]
-                                for v in shared_vars
-                            ],
+                            labels=[nodes[v].annotations.esl_info["type_ref"] for v in shared_vars],
                             annotations=dict(
-                                esl_info=dict(
-                                    reason=dict(shared_vars=list(shared_vars))
-                                )
+                                esl_info=dict(reason=dict(shared_vars=list(shared_vars)))
                             ),
                         ),
                         "mbr",
@@ -1532,14 +1414,9 @@ class EdgeFactory:
                             source=d,
                             target=r,
                             kind="mapping_dependency",
-                            labels=[
-                                nodes[v].annotations.esl_info["type_ref"]
-                                for v in shared_vars
-                            ],
+                            labels=[nodes[v].annotations.esl_info["type_ref"] for v in shared_vars],
                             annotations=dict(
-                                esl_info=dict(
-                                    reason=dict(shared_vars=list(shared_vars))
-                                )
+                                esl_info=dict(reason=dict(shared_vars=list(shared_vars)))
                             ),
                         ),
                         "mdr",
@@ -1646,9 +1523,7 @@ def _get_component_behavior_dependency(
             vi, vj = path[0], path[1]
             edges = ev_dict.get((nodes[vi], nodes[vj]), [])
             for e in edges:
-                reasons.update(
-                    e.annotations.esl_info["reason"]["behavior_specifications"]
-                )
+                reasons.update(e.annotations.esl_info["reason"]["behavior_specifications"])
             vrs.extend([nodes[path[0]], nodes[path[-1]]])
         else:
             # Check id none of the intermediate path variables relate to a function
@@ -1663,9 +1538,7 @@ def _get_component_behavior_dependency(
                 for vi, vj in zip(path[:-1], path[1:]):
                     edges = ev_dict.get((nodes[vi], nodes[vj]))
                     for e in edges:
-                        reasons.update(
-                            e.annotations.esl_info["reason"]["behavior_specifications"]
-                        )
+                        reasons.update(e.annotations.esl_info["reason"]["behavior_specifications"])
 
             vrs.extend([nodes[path[0]], nodes[path[-1]]])
 
@@ -1689,9 +1562,7 @@ def _get_component_behavior_dependency(
         return None
 
 
-def _get_paths_between_all(
-    srcs=List[Node], trgs=List[Node], edges=List[Edge]
-) -> List[List[str]]:
+def _get_paths_between_all(srcs=List[Node], trgs=List[Node], edges=List[Edge]) -> List[List[str]]:
     """Compute paths between nodes. Based on depth first search.
 
     Arguments:
@@ -1749,9 +1620,7 @@ def _get_paths(
             paths.append(visited)
         else:
             new_path = deepcopy(visited)
-            paths.extend(
-                _get_paths(src=n, edge_dct=edge_dct, trgs=trgs, visited=new_path)
-            )
+            paths.extend(_get_paths(src=n, edge_dct=edge_dct, trgs=trgs, visited=new_path))
 
     return paths
 
@@ -1797,9 +1666,7 @@ def _get_function_behavior_dependency(
             vi, vj = path[0], path[1]
             edges = ev_dict.get((nodes[vi], nodes[vj]), [])
             for e in edges:
-                reasons.update(
-                    e.annotations.esl_info["reason"]["behavior_specifications"]
-                )
+                reasons.update(e.annotations.esl_info["reason"]["behavior_specifications"])
             vrs.extend([nodes[path[0]], nodes[path[-1]]])
         else:
             # Check id none of the intermediate path variables relate to a function
@@ -1814,9 +1681,7 @@ def _get_function_behavior_dependency(
                 for vi, vj in zip(path[:-1], path[1:]):
                     edges = ev_dict.get((nodes[vi], nodes[vj]))
                     for e in edges:
-                        reasons.update(
-                            e.annotations.esl_info["reason"]["behavior_specifications"]
-                        )
+                        reasons.update(e.annotations.esl_info["reason"]["behavior_specifications"])
 
             vrs.extend([nodes[path[0]], nodes[path[-1]]])
 
@@ -1827,9 +1692,7 @@ def _get_function_behavior_dependency(
             target=trg,
             kind="logical_dependency",
             labels=lbs,
-            annotations=dict(
-                esl_info=dict(reason=dict(behavior_specifications=sorted(reasons)))
-            ),
+            annotations=dict(esl_info=dict(reason=dict(behavior_specifications=sorted(reasons)))),
         )
     else:
         return None
