@@ -105,9 +105,7 @@ class NodeFactory:
                 name="world",
                 kind="component",
                 annotations=dict(
-                    esl_info=dict(
-                        definition_name="world", property_variables=[], comments=[]
-                    )
+                    esl_info=dict(definition_name="world", property_variables=[], comments=[])
                 ),
             ),
             "components",
@@ -157,9 +155,7 @@ class NodeFactory:
             child_inst_map: Dict[ElementaryVarNode, InstNode] = {}
             for arg, param in zip(comp_inst.arguments, comp_inst.compdef.parameters):
                 assert arg.argnode is not None
-                result = make_parameter_instmap(
-                    param, param.node, arg.argnode, inst_map
-                )
+                result = make_parameter_instmap(param, param.node, arg.argnode, inst_map)
                 child_inst_map.update(result)
 
             # Full dotted name.
@@ -167,19 +163,15 @@ class NodeFactory:
 
             # Add component as a node.
             self._add(
-                make_component_node(
-                    c=comp_inst, inst_name=child_inst_name, params=child_inst_map
-                ),
+                make_component_node(c=comp_inst, inst_name=child_inst_name, params=child_inst_map),
                 "components",
             )
-            self._instantiate_component(
-                comp_inst.compdef, child_inst_map, child_inst_name
-            )
+            self._instantiate_component(comp_inst.compdef, child_inst_map, child_inst_name)
 
             # Set parent of child
-            self.node_store.components[
-                child_inst_name
-            ].parent = self.node_store.components[inst_name]
+            self.node_store.components[child_inst_name].parent = self.node_store.components[
+                inst_name
+            ]
 
         # Verify ownership of the variable InstNodes.
         for inst_node in local_varinst_list:
@@ -282,24 +274,16 @@ def make_parameter_instmap(
         assert isinstance(param_node, CompoundVarNode)
         if isinstance(arg_node, CompoundVarNode):
             assert len(param_node.child_nodes) == len(arg_node.child_nodes)
-            for param_child, arg_child in zip(
-                param_node.child_nodes, arg_node.child_nodes
-            ):
+            for param_child, arg_child in zip(param_node.child_nodes, arg_node.child_nodes):
                 child_map.update(
-                    make_parameter_instmap(
-                        param, param_child, arg_child, parent_inst_map
-                    )
+                    make_parameter_instmap(param, param_child, arg_child, parent_inst_map)
                 )
         else:
             assert isinstance(arg_node, GroupNode)
             assert len(param_node.child_nodes) == len(arg_node.child_nodes)
-            for param_child, arg_child in zip(
-                param_node.child_nodes, arg_node.child_nodes
-            ):
+            for param_child, arg_child in zip(param_node.child_nodes, arg_node.child_nodes):
                 child_map.update(
-                    make_parameter_instmap(
-                        param, param_child, arg_child, parent_inst_map
-                    )
+                    make_parameter_instmap(param, param_child, arg_child, parent_inst_map)
                 )
 
         return child_map
@@ -359,9 +343,7 @@ def _make_type_annotations(tdef: types.TypeDef) -> Dict[str, Dict[str, Any]]:
     return dict(esl_info=dict(units=units, domain=domain))
 
 
-def make_variable_node(
-    v: InstNode, type_inst_map: Dict[ElementaryType, TypeDef]
-) -> Node:
+def make_variable_node(v: InstNode, type_inst_map: Dict[ElementaryType, TypeDef]) -> Node:
     """Node creation for a variable.
 
     Arguments:
@@ -479,9 +461,7 @@ def _make_need_annotations(n: Need, inst_prefix: str) -> Dict[str, Dict[str, Any
     )
 
 
-def make_goal_node(
-    g: Goal, inst_name: str, inst_map: Dict[ElementaryVarNode, InstNode]
-) -> Node:
+def make_goal_node(g: Goal, inst_name: str, inst_map: Dict[ElementaryVarNode, InstNode]) -> Node:
     """Goal node creation.
 
     Arguments:
@@ -520,9 +500,7 @@ def _make_goal_annotations(
         subclauses=_make_subclause_annotations(g, inst_map),
     )
 
-    return dict(
-        esl_info=dict(sub_kind="goal", form=g.goal_kind, body=body, comments=g.comments)
-    )
+    return dict(esl_info=dict(sub_kind="goal", form=g.goal_kind, body=body, comments=g.comments))
 
 
 def make_transform_node(
@@ -634,11 +612,7 @@ def _make_design_annotations(
     """
     body = _make_design_rule_annotation(expr=d.expr, inst_map=inst_map)
     subs = _make_subclause_annotations(d, inst_map)
-    return dict(
-        esl_info=dict(
-            form=d.design_kind, body=body, sub_clauses=subs, comments=d.comments
-        )
-    )
+    return dict(esl_info=dict(form=d.design_kind, body=body, sub_clauses=subs, comments=d.comments))
 
 
 def _make_subclause_annotations(
