@@ -17,9 +17,7 @@ comment_header:
 """
 
 
-def _process_comment_header(
-    tags: typing.TokensDict, _accept: str, builder: "AstBuilder"
-) -> None:
+def _process_comment_header(tags: typing.TokensDict, _accept: str, builder: "AstBuilder") -> None:
     builder.notify_new_section(tags["comment"][0], False)
 
 
@@ -34,9 +32,7 @@ comment_line:
 """
 
 
-def _process_comment_name(
-    tags: typing.TokensDict, _accept: str, builder: "AstBuilder"
-) -> None:
+def _process_comment_name(tags: typing.TokensDict, _accept: str, builder: "AstBuilder") -> None:
     current_comp = builder.compdef_builder.current_component
     assert current_comp is not None
     current_comp.add_comment(tags["name"][0])
