@@ -21,9 +21,7 @@ define_component:
 """
 
 
-def _process_compdef(
-    tags: typing.TokensDict, _accept: str, builder: "AstBuilder"
-) -> None:
+def _process_compdef(tags: typing.TokensDict, _accept: str, builder: "AstBuilder") -> None:
     if "world" in tags:
         pos_tok = tags["world"][0]
         name_tok = None
