@@ -18,9 +18,7 @@ needs_header:
 """
 
 
-def _process_need_header(
-    tags: typing.TokensDict, _accept: str, builder: "AstBuilder"
-) -> None:
+def _process_need_header(tags: typing.TokensDict, _accept: str, builder: "AstBuilder") -> None:
     builder.notify_new_section(tags["need"][0], False)
 
 
