@@ -19,9 +19,7 @@ variable_header:
 """
 
 
-def _process_varheader(
-    tags: typing.TokensDict, _accept: str, builder: "AstBuilder"
-) -> None:
+def _process_varheader(tags: typing.TokensDict, _accept: str, builder: "AstBuilder") -> None:
     builder.notify_new_section(tags["variable"][0], False)
 
 
@@ -41,9 +39,7 @@ variable_line:
 """
 
 
-def _process_varline(
-    tags: typing.TokensDict, _accept: str, builder: "AstBuilder"
-) -> None:
+def _process_varline(tags: typing.TokensDict, _accept: str, builder: "AstBuilder") -> None:
     varnames = tags["varname"]
     typename = tags["typename"][0]
     variables = [VarParam(True, vname, typename) for vname in varnames]
