@@ -19,9 +19,7 @@ define_verb:
 """
 
 
-def _process_define_verb(
-    tags: typing.TokensDict, _accept: str, builder: "AstBuilder"
-) -> None:
+def _process_define_verb(tags: typing.TokensDict, _accept: str, builder: "AstBuilder") -> None:
     builder.notify_new_section(tags["define"][0], True)
 
 
@@ -37,9 +35,7 @@ verb_prepos:
 """
 
 
-def _process_verb_def(
-    tags: typing.TokensDict, _accept: str, builder: "AstBuilder"
-) -> None:
+def _process_verb_def(tags: typing.TokensDict, _accept: str, builder: "AstBuilder") -> None:
     verb = tags["verb"][0]
     prepos = tags["prepos"][0]
     builder.add_verbdef(verb, prepos)
