@@ -118,9 +118,7 @@ class CompDefChildBuilders:
         """Forward call to variable group builder."""
         self.vargroup_builder.vgroup_add_vars(varname_toks)
 
-    def add_compinst(
-        self, inst_name_tok: "Token", def_name_tok: "Token", has_arguments: bool
-    ):
+    def add_compinst(self, inst_name_tok: "Token", def_name_tok: "Token", has_arguments: bool):
         """Forward call to component instance builder."""
         self.compinst_builder.add_compinst(inst_name_tok, def_name_tok, has_arguments)
 
@@ -250,9 +248,7 @@ class CompDefChildBuilders:
         self.behavior_builder.finish_comp(comp_def, spec)
         self.design_builder.finish_comp(comp_def, spec)
         self.need_builder.finish_comp(comp_def, spec)
-        self.comment_builder.finish_comp(
-            comp_def, doc_distributor
-        )  # Must be final build step.
+        self.comment_builder.finish_comp(comp_def, doc_distributor)  # Must be final build step.
 
         # Check for unique labels within the scope of each comp_def.
         for labeled_elements in self.elements_by_label.values():
@@ -306,17 +302,13 @@ class CompDefChildBuilders:
         """A parameter section was found, check if it is allowed."""
         if self.name_tok is None:  # We're processing 'world'
             # Parameter section not allowed in 'world'.
-            self.diag_store.add(
-                diagnostics.E201("parameter", "world", pos_tok.get_location())
-            )
+            self.diag_store.add(diagnostics.E201("parameter", "world", pos_tok.get_location()))
 
     def notify_transform_section(self, pos_tok: "Token"):
         """A transform section was found, check if it is allowed."""
         if self.name_tok is None:  # We're processing 'world'
             # Transformation section not allowed in 'world'.
-            self.diag_store.add(
-                diagnostics.E201("transformation", "world", pos_tok.get_location())
-            )
+            self.diag_store.add(diagnostics.E201("transformation", "world", pos_tok.get_location()))
 
 
 class ComponentDefBuilder:
@@ -378,9 +370,7 @@ class ComponentDefBuilder:
         elif len(worlds) > 1:
             locs = [world.pos_tok.get_location() for world in worlds]
             self.diag_store.add(
-                diagnostics.E200(
-                    "world", "component instance", location=locs[0], dupes=locs
-                )
+                diagnostics.E200("world", "component instance", location=locs[0], dupes=locs)
             )
 
         for cdefs in compdefs.values():
@@ -390,9 +380,7 @@ class ComponentDefBuilder:
                 assert cdefs[0].name_tok is not None
                 name = cdefs[0].name_tok.tok_text
                 self.diag_store.add(
-                    diagnostics.E200(
-                        name, "component definition", location=locs[0], dupes=locs
-                    )
+                    diagnostics.E200(name, "component definition", location=locs[0], dupes=locs)
                 )
 
         # Components to use.
@@ -429,7 +417,5 @@ class ComponentDefBuilder:
             assert cycle[0].data is not None
             comp_name = cycle[0].data.name_tok.tok_text  # Cannot be world!
             self.diag_store.add(
-                diagnostics.E204(
-                    comp_name, "component definition", location=locs[0], cycle=locs
-                )
+                diagnostics.E204(comp_name, "component definition", location=locs[0], cycle=locs)
             )
