@@ -291,9 +291,7 @@ class TypeBuilder:
                 # Parent is a compound, type cannot be extended.
                 if is_extended:
                     self.diag_store.add(
-                        diagnostics.E215(
-                            parent_name.tok_text, location=parent_name.get_location()
-                        )
+                        diagnostics.E215(parent_name.tok_text, location=parent_name.get_location())
                     )
                     return None
 
@@ -329,9 +327,7 @@ class TypeBuilder:
 
                 if unit_text in available_units:
                     self.diag_store.add(
-                        diagnostics.W200(
-                            unit.tok_text, "unit", location=unit.get_location()
-                        )
+                        diagnostics.W200(unit.tok_text, "unit", location=unit.get_location())
                     )
                     continue  # Silently discard duplicates.
 
@@ -339,9 +335,7 @@ class TypeBuilder:
                 available_units[unit_text] = unit
 
         # Build intervals
-        type_intervals: Optional[
-            List[Tuple[Optional[exprs.Value], Optional[exprs.Value]]]
-        ]
+        type_intervals: Optional[List[Tuple[Optional[exprs.Value], Optional[exprs.Value]]]]
         type_intervals = None
 
         if ival_spec:
@@ -385,9 +379,7 @@ class TypeBuilder:
             return True
         return False
 
-    def _make_typedef(
-        self, tdef: TempTypeDef, resolved_types: Dict[str, types.TypeDef]
-    ):
+    def _make_typedef(self, tdef: TempTypeDef, resolved_types: Dict[str, types.TypeDef]):
         """Add the type definition to the resolved collection. It is assumed the
         dependencies are already available (as ensured by the Orderer).
         """
@@ -412,9 +404,7 @@ class TypeBuilder:
         assert typedef.name.tok_text not in resolved_types
         resolved_types[typedef.name.tok_text] = typedef
 
-    def _make_bundledef(
-        self, bdef: TempBundleDef, resolved_types: Dict[str, types.TypeDef]
-    ):
+    def _make_bundledef(self, bdef: TempBundleDef, resolved_types: Dict[str, types.TypeDef]):
         """Add the bundle definition to the resolved collection. It is assumed the
         dependencies are already available (as ensured by the Orderer).
         """
@@ -466,9 +456,7 @@ class TypeBuilder:
         cons_spec: Optional[exprs.Value],
     ):
         """The parser found a new type definition entry, store it."""
-        temp_tdef = TempTypeDef(
-            type_name, parent_name, enum_spec, unit_spec, ival_spec, cons_spec
-        )
+        temp_tdef = TempTypeDef(type_name, parent_name, enum_spec, unit_spec, ival_spec, cons_spec)
         self.type_defs.append(temp_tdef)
         self.current_bundle = None
 
@@ -485,14 +473,10 @@ class TypeBuilder:
     ):
         """A new field in the current bundle has been found by the parser, add it."""
         temp_fdef = TempFieldDef(field_name, type_name)
-        assert (
-            self.current_bundle
-        ), "Trying to add a bundle field outside a type section."
+        assert self.current_bundle, "Trying to add a bundle field outside a type section."
         self.current_bundle.bundle_fields.append(temp_fdef)
 
-    def check_unit(
-        self, value: Optional[exprs.Value], available_units: Dict[str, "Token"]
-    ) -> None:
+    def check_unit(self, value: Optional[exprs.Value], available_units: Dict[str, "Token"]) -> None:
         """Check whether the unit possibly specified in 'value' is available for use.
         Report an error if it is not available.
         """
@@ -509,6 +493,4 @@ class TypeBuilder:
         unit_text = value.unit.tok_text
         if unit_text.startswith("[") and unit_text.endswith("]"):
             unit_text = unit_text[1:-1]
-        self.diag_store.add(
-            diagnostics.E219(unit_text, location=value.unit.get_location())
-        )
+        self.diag_store.add(diagnostics.E219(unit_text, location=value.unit.get_location()))
