@@ -29,9 +29,7 @@ def list_locales():
 
     here = Path(__file__).parent
     return list(
-        p.stem
-        for p in here.glob("*")
-        if p.suffix == ".py" and p.name not in {"__init__.py"}
+        p.stem for p in here.glob("*") if p.suffix == ".py" and p.name not in {"__init__.py"}
     )
 
 
