@@ -3,11 +3,12 @@
 from collections import defaultdict
 from typing import Any, Dict, Generator, List
 
+from ragraph.graph import Graph
+from ragraph.node import Node
+
 import raesl.doc.lines as lns
 from raesl import logger
 from raesl.doc.locales import hookimpl, pm
-from ragraph.graph import Graph
-from ragraph.node import Node
 
 LineGen = Generator[str, None, None]
 
@@ -194,9 +195,7 @@ def design_rule_line(r: Dict[str, str]):
         unit = r["bound"]["unit"]
 
     if r["auxiliary"] == "won't":
-        return "{} {} nimmer {} {} {} {}".format(
-            s, aux[0], comparison, value, unit, aux[1]
-        )
+        return "{} {} nimmer {} {} {} {}".format(s, aux[0], comparison, value, unit, aux[1])
     else:
         return "{} {} {} {} {} {}".format(s, aux[0], comparison, value, unit, aux[1])
 
@@ -223,9 +222,7 @@ def then_clause_rule_line(r: Dict[str, str]):
         unit = r["bound"]["unit"]
 
     if r["auxiliary"] == "won't":
-        return "{} {} nimmer {} {} {} {}".format(
-            s, aux[0], comparison, value, unit, aux[1]
-        )
+        return "{} {} nimmer {} {} {} {}".format(s, aux[0], comparison, value, unit, aux[1])
     else:
         return "{} {} {} {} {} {}".format(aux[0], s, comparison, value, unit, aux[1])
 
@@ -262,7 +259,7 @@ def subclause_rule_line(r: Dict[str, str]):
 
 
 @hookimpl
-def function_spec_node(node: Node, graph: Graph) -> LineGen:
+def function_spec_node(node: Node, graph: Graph, html: bool) -> LineGen:
     if node.annotations.esl_info["sub_kind"] == "transformation":
         comp = node.annotations.esl_info["body"]["active"].split(".")[-1]
         aux = node.annotations.esl_info["body"]["auxiliary"]
@@ -275,9 +272,7 @@ def function_spec_node(node: Node, graph: Graph) -> LineGen:
                             graph[flow].annotations.esl_info["bundle_root_name"]
                             if graph[flow].annotations.esl_info["bundle_root_name"]
                             else flow.split(".")[-1]
-                            for flow in node.annotations.esl_info["body"][
-                                "input_variables"
-                            ]
+                            for flow in node.annotations.esl_info["body"]["input_variables"]
                         ]
                     )
                 )
@@ -292,9 +287,7 @@ def function_spec_node(node: Node, graph: Graph) -> LineGen:
                             graph[flow].annotations.esl_info["bundle_root_name"]
                             if graph[flow].annotations.esl_info["bundle_root_name"]
                             else flow.split(".")[-1]
-                            for flow in node.annotations.esl_info["body"][
-                                "output_variables"
-                            ]
+                            for flow in node.annotations.esl_info["body"]["output_variables"]
                         ]
                     )
                 )
@@ -309,23 +302,15 @@ def function_spec_node(node: Node, graph: Graph) -> LineGen:
                 comp, in_flows, prep, out_flows, make_predicate(verb)
             )
         elif aux == "could":
-            line = "{} zou {} {} {} kunnen {}".format(
-                comp, in_flows, prep, out_flows, verb
-            )
+            line = "{} zou {} {} {} kunnen {}".format(comp, in_flows, prep, out_flows, verb)
         elif aux == "won't":
-            line = "{} zal nimmer {} {} {} {}".format(
-                comp, in_flows, prep, out_flows, verb
-            )
+            line = "{} zal nimmer {} {} {} {}".format(comp, in_flows, prep, out_flows, verb)
         elif aux == "shall":
             line = "{} zal {} {} {} {}".format(comp, in_flows, prep, out_flows, verb)
         elif aux == "is":
-            line = "{} vervult het {} van {} {} {}".format(
-                comp, verb, in_flows, prep, out_flows
-            )
+            line = "{} vervult het {} van {} {} {}".format(comp, verb, in_flows, prep, out_flows)
         else:
-            line = "{} {} {} {} {} {}".format(
-                comp, aux, verb, in_flows, prep, out_flows
-            )
+            line = "{} {} {} {} {} {}".format(comp, aux, verb, in_flows, prep, out_flows)
 
         # Bundle root varaible dict
         brvdict = defaultdict(list)
@@ -359,25 +344,17 @@ def function_spec_node(node: Node, graph: Graph) -> LineGen:
         passive = node.annotations.esl_info["body"]["passive"].split(".")[-1]
 
         if aux == "must":
-            line = "{} dient {} {} {} {}".format(
-                active, flows, prep, passive, make_predicate(verb)
-            )
+            line = "{} dient {} {} {} {}".format(active, flows, prep, passive, make_predicate(verb))
         elif aux == "should":
             line = "{} behoort {} {} {} {}".format(
                 active, flows, prep, passive, make_predicate(verb)
             )
         elif aux == "could":
-            line = "{} zou {} {} {} kunnen {}".format(
-                active, flows, prep, passive, verb
-            )
+            line = "{} zou {} {} {} kunnen {}".format(active, flows, prep, passive, verb)
         elif aux == "won't":
-            line = "{} zal nimmer {} {} {} {}".format(
-                active, flows, prep, passive, verb
-            )
+            line = "{} zal nimmer {} {} {} {}".format(active, flows, prep, passive, verb)
         elif aux == "does":
-            line = "{} vervult het {} van {} {} {}".format(
-                active, verb, flows, prep, passive
-            )
+            line = "{} vervult het {} van {} {} {}".format(active, verb, flows, prep, passive)
         elif aux == "shall":
             line = "{} zal {} {} {} {}".format(active, flows, prep, passive, verb)
         else:
@@ -408,24 +385,19 @@ def function_spec_node(node: Node, graph: Graph) -> LineGen:
 
 
 @hookimpl
-def design_spec_node(node: Node, graph: Graph) -> LineGen:
+def design_spec_node(node: Node, graph: Graph, html: bool) -> LineGen:
     line = " of ".join([design_rule_line(r) for r in node.annotations.esl_info["body"]])
     if node.annotations.esl_info.get("sub_clauses"):
         yield lns.cap(line) + ", waarbij:\n"
         yield from lns.unordered(
-            [
-                "\n".join(subclause_line(s=sc))
-                for sc in node.annotations.esl_info["sub_clauses"]
-            ]
+            ["\n".join(subclause_line(s=sc)) for sc in node.annotations.esl_info["sub_clauses"]]
         )
     else:
         yield lns.snt(line)
 
     bvars = [
         v
-        for v in lns.get_design_rule_line_vars(
-            rules=node.annotations.esl_info["body"], g=graph
-        )
+        for v in lns.get_design_rule_line_vars(rules=node.annotations.esl_info["body"], g=graph)
         if v.annotations.esl_info["bundle_root_name"]
     ]
 
@@ -434,19 +406,16 @@ def design_spec_node(node: Node, graph: Graph) -> LineGen:
 
 
 @hookimpl
-def behavior_spec_node(node: Node, graph: Graph) -> LineGen:
+def behavior_spec_node(node: Node, graph: Graph, html: bool) -> LineGen:
     clauses = []
     for case in node.annotations.esl_info["cases"]:
         yield lns.cap("situatie {}:\n".format(lns.emph(case["name"])))
         yield ""
-        yield "als:\n"
-        yield from lns.unordered(
-            ["\n".join(subclause_line(s=sc)) for sc in case["when_clauses"]]
-        )
-        yield "dan:\n"
-        yield from lns.unordered(
-            ["\n".join(then_clause_line(s=sc)) for sc in case["then_clauses"]]
-        )
+        yield "als:"
+        yield from lns.unordered(["\n".join(subclause_line(s=sc)) for sc in case["when_clauses"]])
+        yield "\n"
+        yield "dan:"
+        yield from lns.unordered(["\n".join(then_clause_line(s=sc)) for sc in case["then_clauses"]])
         clauses += case["when_clauses"] + case["then_clauses"]
 
     default = node.annotations.esl_info.get("default")
@@ -469,7 +438,7 @@ def behavior_spec_node(node: Node, graph: Graph) -> LineGen:
 
 
 @hookimpl
-def need_node(node: Node, graph: Graph) -> LineGen:
+def need_node(node: Node, graph: Graph, html: bool) -> LineGen:
     subject = node.annotations.esl_info["subject"]
     line = "{} {}".format(
         node.annotations.esl_info["subject"].split(".")[-1],
