@@ -1,11 +1,12 @@
 from copy import deepcopy
 from typing import Generator, List, Optional
 
+from ragraph.graph import Graph
+from ragraph.node import Node
+
 import raesl.doc.lines as lns
 from raesl.doc import utils
 from raesl.doc.locales import _, pm
-from ragraph.graph import Graph
-from ragraph.node import Node
 
 LineGen = Generator[str, None, None]
 TABLE_SINGLE = (
@@ -58,8 +59,7 @@ def node_decomp_level(
     if rich == "tex" or rich == "md":
         yield lns.snt(
             _(
-                "in Figure \\ref{{{}}} the associated design-structure-matrix (DSM) is "
-                "shown"
+                "in Figure \\ref{{{}}} the associated design-structure-matrix (DSM) is " "shown"
             ).format("fig:mdmlevel" + str(depth + 1))
         )
         yield lns.snt(
@@ -72,9 +72,7 @@ def node_decomp_level(
 
 def global_needs_and_designs(h: int = 1):
     """Yield a global need and design specification intro section."""
-    yield lns.header(
-        h, "{}".format(_("system-wide qualitative and quantitative specifications"))
-    )
+    yield lns.header(h, "{}".format(_("system-wide qualitative and quantitative specifications")))
 
     yield lns.snt(
         _(
@@ -123,7 +121,6 @@ def get_node_table(
     for key, comments in plain_comments + list(
         node.annotations.esl_info["tagged_comments"].items()
     ):
-
         table.append("| {} |".format(lns.boldhead(_(key)).replace("\n", "")))
         table.append(TABLE_SINGLE)
         for comment in comments:
@@ -154,9 +151,9 @@ def comp_node_goal_reqs(node: Node, g: Graph, h: int = 1) -> LineGen:
         temp = deepcopy(gl)
         temp.annotations.esl_info["comments"].append(
             lns.snt(
-                _(
-                    "this goal function requirement automatically migrated from {}"
-                ).format(lns.node_path(temp.annotations.esl_info["body"]["active"]))
+                _("this goal function requirement automatically migrated from {}").format(
+                    lns.node_path(temp.annotations.esl_info["body"]["active"])
+                )
             )
         )
         temp.annotations.esl_info["body"]["active"] = node.name
@@ -181,9 +178,9 @@ def comp_node_goal_cons(node: Node, g: Graph, h: int = 1) -> LineGen:
         temp = deepcopy(gl)
         temp.annotations.esl_info["comments"].append(
             lns.snt(
-                _(
-                    "this goal function constraint automatically migrated from {}"
-                ).format(lns.node_path(temp.annotations.esl_info["body"]["active"]))
+                _("this goal function constraint automatically migrated from {}").format(
+                    lns.node_path(temp.annotations.esl_info["body"]["active"])
+                )
             )
         )
         temp.annotations.esl_info["body"]["active"] = node.name
@@ -226,9 +223,7 @@ def comp_node_transformation_cons(node: Node, g: Graph, h: int = 1) -> LineGen:
 
     for tr in trs:
         subs = [
-            e.target.name
-            for e in g.edges
-            if e.source == tr and e.kind == "traceability_dependency"
+            e.target.name for e in g.edges if e.source == tr and e.kind == "traceability_dependency"
         ]
         table = get_node_table(tr, graph=g, sub_nodes=subs)
         yield from table
@@ -385,9 +380,7 @@ def relation_node_table(r: Node, g: Graph) -> List:
             table.append("|    |")
         table.append(TABLE_SINGLE)
 
-    plain_comments = (
-        [("comments", ri.get("comments", []))] if ri.get("comments", []) else []
-    )
+    plain_comments = [("comments", ri.get("comments", []))] if ri.get("comments", []) else []
 
     for key, comments in plain_comments + list(ri["tagged_comments"].items()):
         table.append("| {} |".format(lns.boldhead(_(key)).replace("\n", "")))
@@ -428,6 +421,7 @@ def comp_node_props(node: Node, g: Graph, h: int) -> LineGen:
         return
 
     name = node.name.split(".")[-1]
+    yield lns.boldhead(_("properties") + ":")
     yield lns.cap(_("the following properties are specified for {}").format(name)) + ":"
     yield from lns.unordered(sorted([p.name.split(".")[-1] for p in props]))
 
@@ -552,9 +546,7 @@ def get_var_table_row_elements(g: Graph, v: Node) -> str:
         if not is_enum:
             domain = ", ".join(intervals)
         else:
-            domain = _("enumeration of ") + pm.hook.linguistic_enumeration(
-                items=intervals
-            )
+            domain = _("enumeration of ") + pm.hook.linguistic_enumeration(items=intervals)
     else:
         domain = ""
     if t.annotations.esl_info.get("units"):
