@@ -10,9 +10,7 @@ from raesl import logger
 
 
 @click.command("excel")
-@click.argument(
-    "paths", nargs=-1, type=click.Path(exists=True, file_okay=True, dir_okay=True)
-)
+@click.argument("paths", nargs=-1, type=click.Path(exists=True, file_okay=True, dir_okay=True))
 @click.option(
     "--output",
     "-o",
