@@ -13,9 +13,7 @@ from ragraph.graph import Graph
 from ragraph.node import Node
 
 
-def add_components_sheet(
-    wb: Workbook, components: List[Node]
-) -> Tuple[Worksheet, List[Node]]:
+def add_components_sheet(wb: Workbook, components: List[Node]) -> Tuple[Worksheet, List[Node]]:
     """Add a components overview sheet to an Excel workbook.
 
     Arguments:
@@ -90,30 +88,22 @@ def add_goals_sheet(
         [
             r
             for c in components
-            for r in doc_utils.get_component_goals(
-                c, graph, constraint=False, inherited=False
-            )
+            for r in doc_utils.get_component_goals(c, graph, constraint=False, inherited=False)
         ]
         + [
             r
             for c in components
-            for r in doc_utils.get_component_goals(
-                c, graph, constraint=False, inherited=True
-            )
+            for r in doc_utils.get_component_goals(c, graph, constraint=False, inherited=True)
         ]
         + [
             r
             for c in components
-            for r in doc_utils.get_component_goals(
-                c, graph, constraint=True, inherited=False
-            )
+            for r in doc_utils.get_component_goals(c, graph, constraint=True, inherited=False)
         ]
         + [
             r
             for c in components
-            for r in doc_utils.get_component_goals(
-                c, graph, constraint=True, inherited=True
-            )
+            for r in doc_utils.get_component_goals(c, graph, constraint=True, inherited=True)
         ]
     )
 
@@ -283,11 +273,7 @@ def add_designs_sheet(
 
     # Select requirements.
     requirements = utils.dedupe(
-        [
-            r
-            for c in components
-            for r in doc_utils.get_component_designs(c, graph, constraint=False)
-        ]
+        [r for c in components for r in doc_utils.get_component_designs(c, graph, constraint=False)]
         + [
             r
             for c in components
@@ -320,20 +306,15 @@ def add_designs_sheet(
                 node_path(requirement.name, italic=False, arrows=False, skip="world"),
                 utils.parent_def(graph, requirement),
                 info["form"],
-                var_path(
-                    graph[body["subject"]], italic=False, arrows=False, skip="world"
-                ),
-                "{}{}".format(
-                    "EITHER " if len(info["body"]) > 1 else "", body["auxiliary"]
-                ),
+                var_path(graph[body["subject"]], italic=False, arrows=False, skip="world"),
+                "{}{}".format("EITHER " if len(info["body"]) > 1 else "", body["auxiliary"]),
                 body["comparison"],
                 "{} {}".format(body["bound"]["value"], body["bound"]["unit"]),
                 text.subclauses_text(requirement, graph, skip="world", spaces=0),
                 utils.format_multiline(info["comments"]),
             ]
             tagged_content = [
-                utils.format_multiline(info["tagged_comments"].get(tag, []))
-                for tag in tags
+                utils.format_multiline(info["tagged_comments"].get(tag, [])) for tag in tags
             ]
             ws.append(default_content + tagged_content)
             rows += 1
