@@ -71,6 +71,4 @@ def mdm(
         if not style.piemap.fields:
             style.piemap.fields = edge_weights
 
-    return ragraph.plot.mdm(
-        leafs=view.nodes, edges=view.edges, show=False, style=style, sort=False
-    )
+    return ragraph.plot.mdm(leafs=view.nodes, edges=view.edges, show=False, style=style, sort=False)
