@@ -19,9 +19,7 @@ def serve(port: Optional[int] = None):
     try:
         from raesl.server.server import ls
     except ImportError:
-        logger.error(
-            "Missing dependencies. Make sure the 'server' extras are installed."
-        )
+        logger.error("Missing dependencies. Make sure the 'server' extras are installed.")
         return
 
     if port is None:
